**Example 1: 初始化用户的合规基线检环境**

在用户首次进入合规安全功能的场景下，调用此接口为用户初始化环境，分配资源和数据。

Input: 

```
tccli tcss InitializeUserComplianceEnvironment --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "xxxxx"
    }
}
```

